@@ -1,5 +1,5 @@
 /* dh-exec-install.c -- Wrapper around dh-exec-install-magic.
- * Copyright (C) 2011  Gergely Nagy <algernon@debian.org>
+ * Copyright (C) 2011, 2013  Gergely Nagy <algernon@debian.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,16 +18,15 @@
 #define _GNU_SOURCE
 
 #include <fnmatch.h>
+#include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 
 #include "dh-exec.lib.h"
 
-const char *DH_EXEC_CMD_PREFIX = "dh-exec-install-";
-
-int
-main (int argc, char *argv[])
+static int
+preamble(int argc, char *argv[])
 {
   const char *src = dh_exec_source (argc, 1, argv);
 
@@ -45,7 +44,7 @@ main (int argc, char *argv[])
     {
       /* Source is stdin, we're piped, ignore it. */
       if (argc < 2)
-        return dh_exec_ignore (NULL);
+        exit (dh_exec_ignore (NULL));
       else
         {
           /* Source is from the command-line directly, raise an
@@ -57,5 +56,9 @@ main (int argc, char *argv[])
         }
     }
 
-  return dh_exec_main (argc, argv);
+  return 0;
 }
+
+#define dh_exec_simple_preamble preamble
+
+#include "dh-exec.simple.c"
