@@ -1,5 +1,5 @@
 /* dh-exec.c -- Wrapper around dh-exec-* commands.
- * Copyright (C) 2011-2012  Gergely Nagy <algernon@debian.org>
+ * Copyright (C) 2011-2013  Gergely Nagy <algernon@debian.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -137,7 +137,7 @@ dh_exec_version (void)
 {
   printf ("dh-exec " PACKAGE_VERSION "\n"
           "\n"
-          "Copyright (C) 2011-2012 Gergely Nagy <algernon@debian.org>\n"
+          "Copyright (C) 2011-2013 Gergely Nagy <algernon@debian.org>\n"
           "This is free software; see the source for copying conditions.  There is NO\n"
           "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
           "\n"
@@ -149,7 +149,9 @@ static int
 dh_exec_list_filter (const struct dirent *entry)
 {
   if (strncmp (entry->d_name, DH_EXEC_CMD_PREFIX,
-               strlen (DH_EXEC_CMD_PREFIX)) != 0)
+               strlen (DH_EXEC_CMD_PREFIX)) != 0 ||
+      strncmp (entry->d_name + strlen (DH_EXEC_CMD_PREFIX), "strip",
+               strlen ("strip")) == 0)
     return 0;
   return 1;
 }
@@ -356,8 +358,7 @@ main (int argc, char *argv[])
 
   dh_exec_cmdlist_free (dhe_commands);
 
-  if (pipeline_get_ncommands (p) == 0)
-    pipeline_command_args (p, "cat", NULL);
+  dh_exec_pipeline_add (p, "dh-exec-strip");
 
   if (no_act)
     {
