@@ -1,5 +1,5 @@
 /* dh-exec.lib.c -- Wrapper around dh-exec-* commands.
- * Copyright (C) 2011-2012  Gergely Nagy <algernon@debian.org>
+ * Copyright (C) 2011-2013  Gergely Nagy <algernon@debian.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,12 @@
 #define DH_EXEC_SCRIPTDIR "/usr/share/dh-exec"
 #define DH_EXEC_LIBDIR "/usr/lib/dh-exec"
 
+#ifndef DH_EXEC_CMD_ALWAYS
+#define DH_EXEC_CMD_ALWAYS 0
+#endif
+
+static const char *DH_EXEC_CMD_PREFIX;
+
 const char *
 dh_exec_scriptdir (void)
 {
@@ -81,6 +87,9 @@ dh_exec_script_allowed (const char *fn)
   char *e;
   char *needle;
 
+  if (DH_EXEC_CMD_ALWAYS)
+    return 0;
+
   e = getenv ("DH_EXEC_SCRIPTS");
   if (!e)
     return 0;
@@ -121,7 +130,7 @@ dh_exec_cmd_filter (const struct dirent *entry)
 }
 
 int
-dh_exec_main (int argc, char *argv[])
+dh_exec_main (const char *cmd_prefix, int argc, char *argv[])
 {
   pipeline *p;
   int status, n;
@@ -135,6 +144,8 @@ dh_exec_main (int argc, char *argv[])
       exit (1);
     }
 
+  DH_EXEC_CMD_PREFIX = cmd_prefix;
+
   n = scandir (dh_exec_scriptdir (), &cmdlist, dh_exec_cmd_filter, alphasort);
   if (n < 0)
     {
