@@ -2,6 +2,34 @@
 
 set -e
 
+cd ${srcdir}
+SRCDIR=$(pwd)
+cd - >/dev/null
+
+cd ${DH_EXEC_BINDIR}
+BINDIR=$(pwd)
+cd - >/dev/null
+
+cd ${DH_EXEC_SCRIPTDIR}
+SCRIPTDIR=$(pwd)
+cd - >/dev/null
+
+cd ${DH_EXEC_LIBDIR}
+LIBDIR=$(pwd)
+cd - >/dev/null
+
+cd ${top_builddir}
+top_builddir=$(pwd)
+cd - >/dev/null
+
+export top_builddir
+export DH_EXEC_BINDIR="${BINDIR}"
+export DH_EXEC_SCRIPTDIR="${SCRIPTDIR}"
+export DH_EXEC_LIBDIR="${LIBDIR}"
+
+install -d t
+cd t
+
 test_lib_cnt=1
 
 tl_plan () {
@@ -46,4 +74,3 @@ tl_expect () {
 }
 
 alias tl_next='test_lib_cnt=$(expr ${test_lib_cnt} + 1)'
-
